<?php

namespace App\Service;

use App\Aggregate\AcceptOrderCommand;
use Symfony\Component\Serializer\SerializerInterface;
use Symfony\Contracts\HttpClient\HttpClientInterface;

readonly class OrderService
{
    public function __construct(
        private HttpClientInterface $crmClient,
        private SerializerInterface $serializer,
        private PricingStrategy $pricingStrategy,
        private ClientService $clientService,
    ) {
    }

    public function acceptOrder(AcceptOrderCommand $command)
    {
        $this->crmClient->request('POST', '/order', [
            'body' => $this->serializer->serialize($command->order, format: 'json')
        ]);

        $totalPrice = $command->order->getTotalPrice($this->pricingStrategy);

        $this->clientService->deduceFromBalance($command->client, $totalPrice);
    }
}
